@@ -12,6 +12,8 @@ import warnings
 import weakref
 
 from azure.core.exceptions import (
+    ClientAuthenticationError,
+    HttpResponseError,
     ResourceNotFoundError,
     ResourceExistsError,
 )
@@ -358,6 +360,10 @@ class AzureBlobFileSystem(AsyncFileSystem):
         ...    client_id=CLIENT_ID, client_secret=CLIENT_SECRET)
     >>> abfs.ls('')
 
+    Authentication with DefaultAzureCredential
+    >>> abfs = AzureBlobFileSystem(account_name="XXXX", anon=False)
+    >>> abfs.ls('')
+
     **  Read files as: **
         -------------
         ddf = dd.read_csv('abfs://container_name/folder/*.csv', storage_options={
@@ -381,6 +387,7 @@ class AzureBlobFileSystem(AsyncFileSystem):
         client_id: str = None,
         client_secret: str = None,
         tenant_id: str = None,
+        anon: bool = True,
         location_mode: str = "primary",
         loop=None,
         asynchronous: bool = False,
@@ -406,6 +413,7 @@ class AzureBlobFileSystem(AsyncFileSystem):
         self.client_id = client_id or os.getenv("AZURE_STORAGE_CLIENT_ID")
         self.client_secret = client_secret or os.getenv("AZURE_STORAGE_CLIENT_SECRET")
         self.tenant_id = tenant_id or os.getenv("AZURE_STORAGE_TENANT_ID")
+        self.anon = anon
         self.location_mode = location_mode
         self.credential = credential
         self.request_session = request_session
@@ -484,6 +492,20 @@ class AzureBlobFileSystem(AsyncFileSystem):
 
         return (async_credential, sync_credential)
 
+    def _get_default_azure_credential(self, **kwargs):
+        try:
+            from azure.identity.aio import (
+                DefaultAzureCredential as AIODefaultAzureCredential,
+            )
+
+            asyncio.get_child_watcher().attach_loop(self.loop)
+            self.credential = AIODefaultAzureCredential()
+            self.do_connect()
+        except:  # noqa: E722
+            raise ClientAuthenticationError(
+                "No explict credentials provided. Failed with DefaultAzureCredential!"
+            )
+
     def do_connect(self):
         """Connect to the BlobServiceClient, using user-specified connection details.
         Tries credentials first, then connection string and finally account key
@@ -519,7 +541,10 @@ class AzureBlobFileSystem(AsyncFileSystem):
                         credential=None,
                         _location_mode=self.location_mode,
                     )
+                elif self.anon is False:
+                    self._get_default_azure_credential()
                 else:
+                    # Fall back to anonymous login, and assume public container
                     self.service_client = AIOBlobServiceClient(
                         account_url=self.account_url
                     )
@@ -1265,9 +1290,24 @@ class AzureBlobFileSystem(AsyncFileSystem):
                         return True
         except KeyError:
             pass
+        except FileNotFoundError:
+            pass
         try:
-            info = await self._info(path)
-            return info["type"] == "file"
+            container_name, path = self.split_path(path)
+            if not path:
+                # A container can not be a file
+                return False
+            else:
+                async with self.service_client.get_blob_client(
+                    container_name, path
+                ) as bc:
+                    props = await bc.get_blob_properties()
+                try:
+                    if props["metadata"]["is_directory"] == "false":
+                        return True
+                except KeyError:
+                    details = self._details([props])
+                    return details["type"] == "file"
         except:  # noqa: E722
             return False
 
@@ -1276,7 +1316,6 @@ class AzureBlobFileSystem(AsyncFileSystem):
 
     async def _isdir(self, path):
         """Is this entry directory-like?"""
-
         if path in self.dircache:
             for fp in self.dircache[path]:
                 # Files will contain themselves in the cache, but
@@ -1284,8 +1323,27 @@ class AzureBlobFileSystem(AsyncFileSystem):
                 if fp["name"] != path:
                     return True
         try:
-            info = await self._info(path)
-            return info["type"] == "directory"
+            container_name, path = self.split_path(path)
+            if not path:
+                return await self._container_exists(container_name)
+            else:
+                path = path.strip("/")
+                key = path + "/"
+                key_length = len(key)
+                async with self.service_client.get_container_client(
+                    container_name
+                ) as cc:
+                    blob_pages = cc.list_blobs(name_starts_with=key)
+                    async for blob in blob_pages:
+                        if (blob["metadata"].get("is_directory", None) == "true") and (
+                            blob["name"] == path
+                        ):
+                            return True
+                        if (blob.name[:key_length] == key) and (
+                            len(blob["name"]) > len(key)
+                        ):
+                            return True
+                    return False
         except IOError:
             return False
 
@@ -1821,6 +1879,8 @@ class AzureBlobFile(AbstractBufferedFile):
                 await self.container_client.delete_blob(self.blob)
             except ResourceNotFoundError:
                 pass
+            except HttpResponseError:
+                pass
             else:
                 await self._reinitiate_async_upload()
 
